@@ -5,7 +5,7 @@
 modname = 'cubicweb_graphql'
 distname = 'cubicweb-graphql'
 
-numversion = (0, 1, 0)
+numversion = (0, 2, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -15,10 +15,10 @@ description = 'GraphQL for CubicWeb'
 web = 'http://www.cubicweb.org/project/%s' % distname
 
 __depends__ = {
-    'cubicweb': '>= 3.26.4',
+    'cubicweb': '>= 3.26.7, < 3.27.0',
     'six': '>= 1.4.0',
-    'graphql-core': '>= 2.0',
-    'graphene': '>= 2.0',
+    'graphql-core': '>= 2.3, <3',
+    'graphene': '>= 2.1, <3',
     'iso8601': None
 }
 __recommends__ = {}
