@@ -24,7 +24,7 @@ import graphene.relay
 from graphql.language import ast
 import json
 
-import utils
+from cubicweb_graphql import utils
 
 TYPE_FIELD_META = "_meta"  # Name of the meta field for a GraphQL object type class
 _TYPE_FIELD_SCHEMA = "__schema"  # Attribute name for the reference to the YAMS entity schema from a GraphQL object type
@@ -201,7 +201,7 @@ class GraphQLSchemaTypes:
         :return: The corresponding union type
         """
         key = tuple(sorted([member.type for member in members]))
-        if self.unions.has_key(key):
+        if key in self.unions:
             return self.unions[key]
         base_classes = (graphene.Union,)
         common = GraphQLSchemaTypes._get_common_ancestor(members)
@@ -278,7 +278,7 @@ class GraphQLSchemaTypes:
             elif relation.final:
                 # handle a primitive type
                 field_type = relation.objects(entity_schema)[0].type
-                if _PRIMITIVES.has_key(field_type):
+                if field_type in _PRIMITIVES:
                     target_type = _PRIMITIVES[field_type]
                     fields[relation.type] = graphene.Field(
                         target_type,
@@ -357,7 +357,7 @@ class GraphQLSchemaTypes:
             elif relation.final:
                 # handle a primitive type
                 field_type = relation.objects(entity_schema)[0].type
-                if _PRIMITIVES.has_key(field_type):
+                if field_type in _PRIMITIVES:
                     target_type = _PRIMITIVES[field_type]
                     fields[relation.type] = graphene.Field(
                         target_type,
@@ -398,7 +398,7 @@ class GraphQLSchemaTypes:
             elif relation.final:
                 # handle a primitive type
                 field_type = relation.objects(entity_schema)[0].type
-                if _PRIMITIVES.has_key(field_type):
+                if field_type in _PRIMITIVES:
                     target_type = _PRIMITIVES[field_type]
                     arguments[relation.type] = graphene.Argument(
                         target_type,
