@@ -19,7 +19,7 @@
 
 from cubicweb.server import hook
 
-from querier import GraphQLQuerier
+from cubicweb_graphql.querier import GraphQLQuerier
 
 
 class GraphQLStartupHook(hook.Hook):
