@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with CubicWeb.  If not, see <http://www.gnu.org/licenses/>.
 """Implement the resolver for CubicWeb entities"""
-from gql_schema import FIELD_SUB_SEPARATOR, TYPE_FIELD_META, ARG_UPDATE_OLD, ARG_UPDATE_NEW, ARG_DELETE_FROM
+from cubicweb_graphql.gql_schema import FIELD_SUB_SEPARATOR, TYPE_FIELD_META, ARG_UPDATE_OLD, ARG_UPDATE_NEW, ARG_DELETE_FROM
 
 CONNECTION = "__connection"  # The key for the current connection in the context of a GraphQL query
 _CACHE = "__cache"  # The key for the object cache in the context of a GraphQL query
